q1ss.binalg.vectorized
======================

.. automodule:: q1ss.binalg.vectorized

BinMat
------

.. autodata:: q1ss.binalg.vectorized.BinMat

BinTensor
---------

.. autodata:: q1ss.binalg.vectorized.BinTensor

BinVec
------

.. autodata:: q1ss.binalg.vectorized.BinVec

BinVecOrMat
-----------

.. autodata:: q1ss.binalg.vectorized.BinVecOrMat

IntVec
------

.. autodata:: q1ss.binalg.vectorized.IntVec

UInt8Vec
--------

.. autodata:: q1ss.binalg.vectorized.UInt8Vec

bits_from_bytes
---------------

.. autodata:: q1ss.binalg.vectorized.bits_from_bytes

bytes_from_bits
---------------

.. autofunction:: q1ss.binalg.vectorized.bytes_from_bits

get_rcef_args
-------------

.. autofunction:: q1ss.binalg.vectorized.get_rcef_args

get_rref_args
-------------

.. autofunction:: q1ss.binalg.vectorized.get_rref_args

make_rcef
---------

.. autodata:: q1ss.binalg.vectorized.make_rcef

make_rref
---------

.. autodata:: q1ss.binalg.vectorized.make_rref

matmul2
-------

.. autofunction:: q1ss.binalg.vectorized.matmul2

matmul_l2r
----------

.. autofunction:: q1ss.binalg.vectorized.matmul_l2r

matmul_l2r_partial
------------------

.. autofunction:: q1ss.binalg.vectorized.matmul_l2r_partial

matmul_r2l
----------

.. autofunction:: q1ss.binalg.vectorized.matmul_r2l

matmul_r2l_partial
------------------

.. autofunction:: q1ss.binalg.vectorized.matmul_r2l_partial

num_rcef_params
---------------

.. autodata:: q1ss.binalg.vectorized.num_rcef_params

num_rref_params
---------------

.. autodata:: q1ss.binalg.vectorized.num_rref_params

pivot_idx
---------

.. autodata:: q1ss.binalg.vectorized.pivot_idx

rcef
----

.. autodata:: q1ss.binalg.vectorized.rcef

rcef_pivot_rows
---------------

.. autodata:: q1ss.binalg.vectorized.rcef_pivot_rows

rcef_residual_vec
-----------------

.. autodata:: q1ss.binalg.vectorized.rcef_residual_vec

rref
----

.. autodata:: q1ss.binalg.vectorized.rref

rref_pivot_cols
---------------

.. autodata:: q1ss.binalg.vectorized.rref_pivot_cols

rref_residual_vec
-----------------

.. autodata:: q1ss.binalg.vectorized.rref_residual_vec
